@@ -1,14 +1,11 @@
-#ifndef lint
-static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/fonts.c,v 1.9 1999/06/02 01:00:38 unammx Exp $";
-#endif
 /*****
 * fonts.c : XmHTML font loading & caching routines.
 *
-* This file Version	$Revision: 1.9 $
+* This file Version	$Revision: 1.10 $
 *
 * Creation date:		Mon Sep 22 09:46:00 GMT+0100 1997
-* Last modification: 	$Date: 1999/06/02 01:00:38 $
-* By:					$Author: unammx $
+* Last modification: 	$Date: 1999/07/29 01:26:28 $
+* By:					$Author: sopwith $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -36,6 +33,11 @@ static char rcsId[]="$Header: /debian/home/gnomecvs/gnome-libs/gtk-xmhtml/fonts.
 /*****
 * ChangeLog 
 * $Log: fonts.c,v $
+* Revision 1.10  1999/07/29 01:26:28  sopwith
+*
+*
+* Fix all warnings.
+*
 * Revision 1.9  1999/06/02 01:00:38  unammx
 *
 * 1999-06-01  Akira Higuchi <a-higuti@math.sci.hokudai.ac.jp>
@@ -1575,7 +1577,7 @@ _XmHTMLUnloadFonts(XmHTMLWidget html)
 #endif
 }
 
-void
+static void
 fillCacheInfo(fontCacheEntry *entry, XmHTMLFontCacheInfo *info)
 {
 	if(entry)
